@@ -18,12 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkonsmqtt.endpoint import endpoint_data
 
 class CreateGroupIdRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'OnsMqtt', '2020-04-20', 'CreateGroupId')
+		RpcRequest.__init__(self, 'OnsMqtt', '2020-04-20', 'CreateGroupId','onsmqtt')
 		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_GroupId(self):
 		return self.get_query_params().get('GroupId')
